=== modified file 'CHANGELOG'
--- CHANGELOG	2012-06-07 11:37:15 +0000
+++ CHANGELOG	2012-06-07 14:00:34 +0000
@@ -24,6 +24,7 @@
     * New tag editor
     * Fix bugs #1003872 and #1002067: Correct titles to Preferences and Synchronization Services Dialogs, by Alan Gomes
     * Improved Export plugin, export to PDF works now, by Izidor Matušov
+    * Added -t option to distinguish between multiple instances of GTG
 
 2012-02-13 Getting Things GNOME! 0.2.9
     * Big refractorization of code, now using liblarch

=== modified file 'gtg'
--- gtg	2012-06-02 11:02:53 +0000
+++ gtg	2012-06-07 14:00:34 +0000
@@ -57,10 +57,15 @@
     parser.add_option('-l', '--local-liblarch', action='store_true',
       dest='local_liblarch', default=False,
       help="Use local liblarch located in ../liblarch if it is posible")
+    parser.add_option('-t', '--title', action='store',
+      help="Use special title for windows' title")
     parser.add_option('-v', '--version', action='store_true',
       dest='print_version', help="Print GTG's version number", default=False)
     (options, args) = parser.parse_args()
 
+    if options.title is not None:
+        info.NAME = options.title
+
     if options.print_version:
         print "GTG (Getting Things Gnome!)", info.VERSION
         print

=== modified file 'scripts/debug.sh'
--- scripts/debug.sh	2012-06-07 13:38:46 +0000
+++ scripts/debug.sh	2012-06-07 14:00:34 +0000
@@ -10,6 +10,7 @@
 dataset="default"
 norun=0
 profile=0
+title=""
 
 # Create execution-time data directory if needed
 mkdir -p tmp
@@ -26,7 +27,8 @@
     n)   norun=1;;
     p)   profile=1;;
     s)   dataset="$OPTARG";;
-    [?]) echo >&2 "Usage: $0 [-s dataset] [-b] [-d] [-l] [-n] [-p]"
+    t)   title="$OPTARG";;
+    [?]) echo >&2 "Usage: $0 [-s dataset] [-t title] [-b] [-d] [-l] [-n] [-p]"
          exit 1;;
     esac
 done
@@ -43,6 +45,17 @@
 export XDG_CACHE_HOME="./tmp/$dataset/xdg/cache"
 export XDG_CONFIG_HOME="./tmp/$dataset/xdg/config"
 
+# Title has to be passed to GTG directly, not through $args
+# title could be more word, and only the first word would be taken
+if [ "$title" = "" ]
+then
+    title="Dev GTG: $(basename `pwd`)"
+    if [ "$dataset" != "default" ]
+    then
+        title="$title ($dataset dataset)"
+    fi
+fi
+
 if [ $norun -eq 0 ]; then
     # Check for liblarch
     if ! ./GTG/tools/import_liblarch.py $liblarchArgs; then
@@ -57,10 +70,10 @@
     fi
 
     if [ $profile -eq 1 ]; then
-	python -m cProfile -o gtg.prof ./gtg $args
-    python ./scripts/profile_interpret.sh
+        python -m cProfile -o gtg.prof ./gtg $args -t "$title"
+        python ./scripts/profile_interpret.sh
     else
-	./gtg $args
+	./gtg $args -t "$title"
     fi
 fi
 

